ADS1015 4 channel differential/single-ended ADC
===============================================

|Build Status| |Coverage Status| |PyPi Package| |Python Versions|

Installing
==========

Stable library from PyPi:

-  Just run ``sudo pip install ads1015``

Latest/development library from GitHub:

-  ``git clone https://github.com/pimoroni/ads1015-python``
-  ``cd ads1015-python``
-  ``sudo ./install.sh``

.. |Build Status| image:: https://travis-ci.com/pimoroni/ads1015-python.svg?branch=master
   :target: https://travis-ci.com/pimoroni/ads1015-python
.. |Coverage Status| image:: https://coveralls.io/repos/github/pimoroni/ads1015-python/badge.svg?branch=master
   :target: https://coveralls.io/github/pimoroni/ads1015-python?branch=master
.. |PyPi Package| image:: https://img.shields.io/pypi/v/ads1015.svg
   :target: https://pypi.python.org/pypi/ads1015
.. |Python Versions| image:: https://img.shields.io/pypi/pyversions/ads1015.svg
   :target: https://pypi.python.org/pypi/ads1015
